AuthorizationCode : A Login with Amazon (LWA) authorization code.
Fields
A Login with Amazon (LWA) authorization code that can be exchanged for a refresh token and access token that authorize you to make calls to a Selling Partner API.
Implementations
sourceimpl AuthorizationCode
impl AuthorizationCode
sourcepub fn new() -> AuthorizationCode
pub fn new() -> AuthorizationCode
A Login with Amazon (LWA) authorization code.